! ############################################################
!            Satellite Data Simulation Unit v2
!                     -  out_micro -
!
! This subroutine writes out the computed brightness temperature.
!
!                 Updated from out-micro.f by H. M. (May, 2009)
!
 Subroutine out_micro ( ifile )
   Use MAINparameters
   Use MCRPparameters
   Implicit NONE
!
! I/O parameters
!
   Integer, intent(in) :: ifile
!
! Local variables
!
   Integer :: i,j,l,m
   character*90 :: pathandfile, filename
!
   filename = CRM_file_list(ifile)
!
! Data dimensions in ascii format
!
   pathandfile = outputdir//trim(filename)//'.mwr.info'
   open(unit= 15, file = pathandfile, form = 'formatted')
!
   write(15,51) ngridx, ngridy, nlyr, deltax, deltay
   write(15,*) 'viewing angle:',inc_angle_mwr
   write(15,*)  mxfreq_microw,'frequencies at ',freq_microw,' GHz.'
   write(15,*) 'The output contains a pair of Tbs at each frequency'// &
               ' for H and V, in this order, polarizations.'
!
   write(15,*) '/ Microphysical setup /'
   write(15,*) ' - Cloud ice: ',trim(cldi%name)//'('//cldi%functype//')'
   Do i = 1, cldi%nparams
      write(15,52) '  PSD parameter #',i,'=',cldi%paramset(i)
   End do
   write(15,*) ' - Cloud water: ',trim(cldw%name)//'('//cldw%functype//')'
   Do i = 1, cldw%nparams
      write(15,52) '  PSD parameter #',i,'=',cldw%paramset(i)
   End do
   write(15,*) ' - Rain: ',trim(rain%name)//'('//rain%functype//')'
   Do i = 1, rain%nparams
      write(15,52) '  PSD parameter #',i,'=',rain%paramset(i)
   End do
   write(15,*) ' - Snow: ',trim(snow%name)//'('//snow%functype//')'
   Do i = 1, snow%nparams
      write(15,52) '  PSD parameter #',i,'=',snow%paramset(i)
   End do
   write(15,*) ' - Graupel: ',trim(grpl%name)//'('//grpl%functype//')'
   Do i = 1, grpl%nparams
      write(15,52) '  PSD parameter #',i,'=',grpl%paramset(i)
   End do
   write(15,*) ' - Hail: ',trim(hail%name)//'('//hail%functype//')'
   Do i = 1, hail%nparams
      write(15,52) '  PSD parameter #',i,'=',hail%paramset(i)
   End do
!
! Computed Tbs in binary format
!
   pathandfile = outputdir//trim(filename)//'.mwr.org'
   open(unit= 20, file = pathandfile, access = 'direct', &
        recl = ngridx*ngridy*mxfreq_microw*2*4)
!
   write(20,rec=1) ((((Tb_out(i,j,l,m),i=1,ngridx),j=1,ngridy), &
                       m=0,1),l=1,mxfreq_microw)
!
51 format(i3,' x ',i3,' (x,y) grid; ',i3,' layers; ', &
         ' deltax = ',f6.2,' km','  deltay = ',f6.2,' km')
52 format(a,i2,a,1P1e10.3)
!
   Close (15)
   Close (20)
   If ( .not. beamconv ) deallocate ( Tb_out )
!
   Return
 End Subroutine out_micro
