! ############################################################
!            Satellite Data Simulation Unit v2
!                     - radar_echo -
!
! This subroutine calculates radar reflectivity and PIA.
!
!               Updated from radar_echo.f by H. M. (May, 2009)
!
 Subroutine radar_echo ( freqcy )
   Use MAINparameters
   Use RDRparameters
   Implicit NONE
!  
! I/O parameters
! 
   real, intent(in) :: freqcy
!
! Local variables
!
! tauext(z=surface to TOA): Extinction optical thickness
!                           measured from TOA
! lambda: Radar echo wavelength [mm]
!
   integer :: nz
   real :: lambda
   real, dimension(:,:),   allocatable :: dtau
   real, dimension(:,:,:), allocatable :: tauext
   real, parameter :: pi = 3.14159265
   real, parameter :: K2 = 0.9255
   real, parameter :: lge = 0.43429448 ! log10(2.71828183)
!
   lambda = 2.997925e2 / freqcy
   allocate ( dtau(ngridx,ngridy), tauext(ngridx,ngridy,0:nlyr) )
!
   tauext(:,:,nlyr) = 0.
   do nz = nlyr, 1, -1
!
      dtau = kexttot(:,:,nz) * (hght_lev(:,:,nz)-hght_lev(:,:,nz-1)) / umu
      tauext(:,:,nz-1) = tauext(:,:,nz) + dtau
!
      where (sbacktot(:,:,nz) <= 0.)
         dBZ(:,:,nz) = -999.
      elsewhere
!
! Units : Z in [mm6/m3], lambda in [mm], sbacktot in [km^-1]
!
         dBZ(:,:,nz) = 10*(log10(lambda)*4 + log10(sbacktot(:,:,nz)) - &
                           log10(K2) - 5*log10(pi) - 2*tauext(:,:,nz)*lge + &
                           log10(1.-exp(-2*dtau)) - log10(2*dtau) + 3.)
      end where
   end do
   PIA = 20*tauext(:,:,0)*lge
!
   Return
 End Subroutine radar_echo

